# ruby-esi

ESI - the Ruby gem for the EVE Swagger Interface

An OpenAPI for EVE Online

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.3.8
- Package version: 0.3.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build ruby-esi.gemspec
```

Then either install the gem locally:

```shell
gem install ./ruby-esi-0.3.0.gem
```
(for development, run `gem install --dev ./ruby-esi-0.3.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'ruby-esi', '~> 0.3.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'ruby-esi', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'ruby-esi'

api_instance = ESI::AllianceApi.new

opts = { 
  datasource: 'tranquility', # String | The server name you would like data from
  if_none_match: 'if_none_match_example', # String | ETag from a previous request. A 304 will be returned if this matches the current ETag
}

begin
  #List all alliances
  result = api_instance.get_alliances(opts)
  p result
rescue ESI::ApiError => e
  puts "Exception when calling AllianceApi->get_alliances: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://esi.evetech.net/latest*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ESI::AllianceApi* | [**get_alliances**](docs/AllianceApi.md#get_alliances) | **GET** /alliances/ | List all alliances
*ESI::AllianceApi* | [**get_alliances_alliance_id**](docs/AllianceApi.md#get_alliances_alliance_id) | **GET** /alliances/{alliance_id}/ | Get alliance information
*ESI::AllianceApi* | [**get_alliances_alliance_id_corporations**](docs/AllianceApi.md#get_alliances_alliance_id_corporations) | **GET** /alliances/{alliance_id}/corporations/ | List alliance's corporations
*ESI::AllianceApi* | [**get_alliances_alliance_id_icons**](docs/AllianceApi.md#get_alliances_alliance_id_icons) | **GET** /alliances/{alliance_id}/icons/ | Get alliance icon
*ESI::AssetsApi* | [**get_characters_character_id_assets**](docs/AssetsApi.md#get_characters_character_id_assets) | **GET** /characters/{character_id}/assets/ | Get character assets
*ESI::AssetsApi* | [**get_corporations_corporation_id_assets**](docs/AssetsApi.md#get_corporations_corporation_id_assets) | **GET** /corporations/{corporation_id}/assets/ | Get corporation assets
*ESI::AssetsApi* | [**post_characters_character_id_assets_locations**](docs/AssetsApi.md#post_characters_character_id_assets_locations) | **POST** /characters/{character_id}/assets/locations/ | Get character asset locations
*ESI::AssetsApi* | [**post_characters_character_id_assets_names**](docs/AssetsApi.md#post_characters_character_id_assets_names) | **POST** /characters/{character_id}/assets/names/ | Get character asset names
*ESI::AssetsApi* | [**post_corporations_corporation_id_assets_locations**](docs/AssetsApi.md#post_corporations_corporation_id_assets_locations) | **POST** /corporations/{corporation_id}/assets/locations/ | Get corporation asset locations
*ESI::AssetsApi* | [**post_corporations_corporation_id_assets_names**](docs/AssetsApi.md#post_corporations_corporation_id_assets_names) | **POST** /corporations/{corporation_id}/assets/names/ | Get corporation asset names
*ESI::BookmarksApi* | [**get_characters_character_id_bookmarks**](docs/BookmarksApi.md#get_characters_character_id_bookmarks) | **GET** /characters/{character_id}/bookmarks/ | List bookmarks
*ESI::BookmarksApi* | [**get_characters_character_id_bookmarks_folders**](docs/BookmarksApi.md#get_characters_character_id_bookmarks_folders) | **GET** /characters/{character_id}/bookmarks/folders/ | List bookmark folders
*ESI::BookmarksApi* | [**get_corporations_corporation_id_bookmarks**](docs/BookmarksApi.md#get_corporations_corporation_id_bookmarks) | **GET** /corporations/{corporation_id}/bookmarks/ | List corporation bookmarks
*ESI::BookmarksApi* | [**get_corporations_corporation_id_bookmarks_folders**](docs/BookmarksApi.md#get_corporations_corporation_id_bookmarks_folders) | **GET** /corporations/{corporation_id}/bookmarks/folders/ | List corporation bookmark folders
*ESI::CalendarApi* | [**get_characters_character_id_calendar**](docs/CalendarApi.md#get_characters_character_id_calendar) | **GET** /characters/{character_id}/calendar/ | List calendar event summaries
*ESI::CalendarApi* | [**get_characters_character_id_calendar_event_id**](docs/CalendarApi.md#get_characters_character_id_calendar_event_id) | **GET** /characters/{character_id}/calendar/{event_id}/ | Get an event
*ESI::CalendarApi* | [**get_characters_character_id_calendar_event_id_attendees**](docs/CalendarApi.md#get_characters_character_id_calendar_event_id_attendees) | **GET** /characters/{character_id}/calendar/{event_id}/attendees/ | Get attendees
*ESI::CalendarApi* | [**put_characters_character_id_calendar_event_id**](docs/CalendarApi.md#put_characters_character_id_calendar_event_id) | **PUT** /characters/{character_id}/calendar/{event_id}/ | Respond to an event
*ESI::CharacterApi* | [**get_characters_character_id**](docs/CharacterApi.md#get_characters_character_id) | **GET** /characters/{character_id}/ | Get character's public information
*ESI::CharacterApi* | [**get_characters_character_id_agents_research**](docs/CharacterApi.md#get_characters_character_id_agents_research) | **GET** /characters/{character_id}/agents_research/ | Get agents research
*ESI::CharacterApi* | [**get_characters_character_id_blueprints**](docs/CharacterApi.md#get_characters_character_id_blueprints) | **GET** /characters/{character_id}/blueprints/ | Get blueprints
*ESI::CharacterApi* | [**get_characters_character_id_corporationhistory**](docs/CharacterApi.md#get_characters_character_id_corporationhistory) | **GET** /characters/{character_id}/corporationhistory/ | Get corporation history
*ESI::CharacterApi* | [**get_characters_character_id_fatigue**](docs/CharacterApi.md#get_characters_character_id_fatigue) | **GET** /characters/{character_id}/fatigue/ | Get jump fatigue
*ESI::CharacterApi* | [**get_characters_character_id_medals**](docs/CharacterApi.md#get_characters_character_id_medals) | **GET** /characters/{character_id}/medals/ | Get medals
*ESI::CharacterApi* | [**get_characters_character_id_notifications**](docs/CharacterApi.md#get_characters_character_id_notifications) | **GET** /characters/{character_id}/notifications/ | Get character notifications
*ESI::CharacterApi* | [**get_characters_character_id_notifications_contacts**](docs/CharacterApi.md#get_characters_character_id_notifications_contacts) | **GET** /characters/{character_id}/notifications/contacts/ | Get new contact notifications
*ESI::CharacterApi* | [**get_characters_character_id_portrait**](docs/CharacterApi.md#get_characters_character_id_portrait) | **GET** /characters/{character_id}/portrait/ | Get character portraits
*ESI::CharacterApi* | [**get_characters_character_id_roles**](docs/CharacterApi.md#get_characters_character_id_roles) | **GET** /characters/{character_id}/roles/ | Get character corporation roles
*ESI::CharacterApi* | [**get_characters_character_id_standings**](docs/CharacterApi.md#get_characters_character_id_standings) | **GET** /characters/{character_id}/standings/ | Get standings
*ESI::CharacterApi* | [**get_characters_character_id_stats**](docs/CharacterApi.md#get_characters_character_id_stats) | **GET** /characters/{character_id}/stats/ | Yearly aggregate stats
*ESI::CharacterApi* | [**get_characters_character_id_titles**](docs/CharacterApi.md#get_characters_character_id_titles) | **GET** /characters/{character_id}/titles/ | Get character corporation titles
*ESI::CharacterApi* | [**post_characters_affiliation**](docs/CharacterApi.md#post_characters_affiliation) | **POST** /characters/affiliation/ | Character affiliation
*ESI::CharacterApi* | [**post_characters_character_id_cspa**](docs/CharacterApi.md#post_characters_character_id_cspa) | **POST** /characters/{character_id}/cspa/ | Calculate a CSPA charge cost
*ESI::ClonesApi* | [**get_characters_character_id_clones**](docs/ClonesApi.md#get_characters_character_id_clones) | **GET** /characters/{character_id}/clones/ | Get clones
*ESI::ClonesApi* | [**get_characters_character_id_implants**](docs/ClonesApi.md#get_characters_character_id_implants) | **GET** /characters/{character_id}/implants/ | Get active implants
*ESI::ContactsApi* | [**delete_characters_character_id_contacts**](docs/ContactsApi.md#delete_characters_character_id_contacts) | **DELETE** /characters/{character_id}/contacts/ | Delete contacts
*ESI::ContactsApi* | [**get_alliances_alliance_id_contacts**](docs/ContactsApi.md#get_alliances_alliance_id_contacts) | **GET** /alliances/{alliance_id}/contacts/ | Get alliance contacts
*ESI::ContactsApi* | [**get_alliances_alliance_id_contacts_labels**](docs/ContactsApi.md#get_alliances_alliance_id_contacts_labels) | **GET** /alliances/{alliance_id}/contacts/labels/ | Get alliance contact labels
*ESI::ContactsApi* | [**get_characters_character_id_contacts**](docs/ContactsApi.md#get_characters_character_id_contacts) | **GET** /characters/{character_id}/contacts/ | Get contacts
*ESI::ContactsApi* | [**get_characters_character_id_contacts_labels**](docs/ContactsApi.md#get_characters_character_id_contacts_labels) | **GET** /characters/{character_id}/contacts/labels/ | Get contact labels
*ESI::ContactsApi* | [**get_corporations_corporation_id_contacts**](docs/ContactsApi.md#get_corporations_corporation_id_contacts) | **GET** /corporations/{corporation_id}/contacts/ | Get corporation contacts
*ESI::ContactsApi* | [**get_corporations_corporation_id_contacts_labels**](docs/ContactsApi.md#get_corporations_corporation_id_contacts_labels) | **GET** /corporations/{corporation_id}/contacts/labels/ | Get corporation contact labels
*ESI::ContactsApi* | [**post_characters_character_id_contacts**](docs/ContactsApi.md#post_characters_character_id_contacts) | **POST** /characters/{character_id}/contacts/ | Add contacts
*ESI::ContactsApi* | [**put_characters_character_id_contacts**](docs/ContactsApi.md#put_characters_character_id_contacts) | **PUT** /characters/{character_id}/contacts/ | Edit contacts
*ESI::ContractsApi* | [**get_characters_character_id_contracts**](docs/ContractsApi.md#get_characters_character_id_contracts) | **GET** /characters/{character_id}/contracts/ | Get contracts
*ESI::ContractsApi* | [**get_characters_character_id_contracts_contract_id_bids**](docs/ContractsApi.md#get_characters_character_id_contracts_contract_id_bids) | **GET** /characters/{character_id}/contracts/{contract_id}/bids/ | Get contract bids
*ESI::ContractsApi* | [**get_characters_character_id_contracts_contract_id_items**](docs/ContractsApi.md#get_characters_character_id_contracts_contract_id_items) | **GET** /characters/{character_id}/contracts/{contract_id}/items/ | Get contract items
*ESI::ContractsApi* | [**get_contracts_public_bids_contract_id**](docs/ContractsApi.md#get_contracts_public_bids_contract_id) | **GET** /contracts/public/bids/{contract_id}/ | Get public contract bids
*ESI::ContractsApi* | [**get_contracts_public_items_contract_id**](docs/ContractsApi.md#get_contracts_public_items_contract_id) | **GET** /contracts/public/items/{contract_id}/ | Get public contract items
*ESI::ContractsApi* | [**get_contracts_public_region_id**](docs/ContractsApi.md#get_contracts_public_region_id) | **GET** /contracts/public/{region_id}/ | Get public contracts
*ESI::ContractsApi* | [**get_corporations_corporation_id_contracts**](docs/ContractsApi.md#get_corporations_corporation_id_contracts) | **GET** /corporations/{corporation_id}/contracts/ | Get corporation contracts
*ESI::ContractsApi* | [**get_corporations_corporation_id_contracts_contract_id_bids**](docs/ContractsApi.md#get_corporations_corporation_id_contracts_contract_id_bids) | **GET** /corporations/{corporation_id}/contracts/{contract_id}/bids/ | Get corporation contract bids
*ESI::ContractsApi* | [**get_corporations_corporation_id_contracts_contract_id_items**](docs/ContractsApi.md#get_corporations_corporation_id_contracts_contract_id_items) | **GET** /corporations/{corporation_id}/contracts/{contract_id}/items/ | Get corporation contract items
*ESI::CorporationApi* | [**get_corporations_corporation_id**](docs/CorporationApi.md#get_corporations_corporation_id) | **GET** /corporations/{corporation_id}/ | Get corporation information
*ESI::CorporationApi* | [**get_corporations_corporation_id_alliancehistory**](docs/CorporationApi.md#get_corporations_corporation_id_alliancehistory) | **GET** /corporations/{corporation_id}/alliancehistory/ | Get alliance history
*ESI::CorporationApi* | [**get_corporations_corporation_id_blueprints**](docs/CorporationApi.md#get_corporations_corporation_id_blueprints) | **GET** /corporations/{corporation_id}/blueprints/ | Get corporation blueprints
*ESI::CorporationApi* | [**get_corporations_corporation_id_containers_logs**](docs/CorporationApi.md#get_corporations_corporation_id_containers_logs) | **GET** /corporations/{corporation_id}/containers/logs/ | Get all corporation ALSC logs
*ESI::CorporationApi* | [**get_corporations_corporation_id_divisions**](docs/CorporationApi.md#get_corporations_corporation_id_divisions) | **GET** /corporations/{corporation_id}/divisions/ | Get corporation divisions
*ESI::CorporationApi* | [**get_corporations_corporation_id_facilities**](docs/CorporationApi.md#get_corporations_corporation_id_facilities) | **GET** /corporations/{corporation_id}/facilities/ | Get corporation facilities
*ESI::CorporationApi* | [**get_corporations_corporation_id_icons**](docs/CorporationApi.md#get_corporations_corporation_id_icons) | **GET** /corporations/{corporation_id}/icons/ | Get corporation icon
*ESI::CorporationApi* | [**get_corporations_corporation_id_medals**](docs/CorporationApi.md#get_corporations_corporation_id_medals) | **GET** /corporations/{corporation_id}/medals/ | Get corporation medals
*ESI::CorporationApi* | [**get_corporations_corporation_id_medals_issued**](docs/CorporationApi.md#get_corporations_corporation_id_medals_issued) | **GET** /corporations/{corporation_id}/medals/issued/ | Get corporation issued medals
*ESI::CorporationApi* | [**get_corporations_corporation_id_members**](docs/CorporationApi.md#get_corporations_corporation_id_members) | **GET** /corporations/{corporation_id}/members/ | Get corporation members
*ESI::CorporationApi* | [**get_corporations_corporation_id_members_limit**](docs/CorporationApi.md#get_corporations_corporation_id_members_limit) | **GET** /corporations/{corporation_id}/members/limit/ | Get corporation member limit
*ESI::CorporationApi* | [**get_corporations_corporation_id_members_titles**](docs/CorporationApi.md#get_corporations_corporation_id_members_titles) | **GET** /corporations/{corporation_id}/members/titles/ | Get corporation's members' titles
*ESI::CorporationApi* | [**get_corporations_corporation_id_membertracking**](docs/CorporationApi.md#get_corporations_corporation_id_membertracking) | **GET** /corporations/{corporation_id}/membertracking/ | Track corporation members
*ESI::CorporationApi* | [**get_corporations_corporation_id_roles**](docs/CorporationApi.md#get_corporations_corporation_id_roles) | **GET** /corporations/{corporation_id}/roles/ | Get corporation member roles
*ESI::CorporationApi* | [**get_corporations_corporation_id_roles_history**](docs/CorporationApi.md#get_corporations_corporation_id_roles_history) | **GET** /corporations/{corporation_id}/roles/history/ | Get corporation member roles history
*ESI::CorporationApi* | [**get_corporations_corporation_id_shareholders**](docs/CorporationApi.md#get_corporations_corporation_id_shareholders) | **GET** /corporations/{corporation_id}/shareholders/ | Get corporation shareholders
*ESI::CorporationApi* | [**get_corporations_corporation_id_standings**](docs/CorporationApi.md#get_corporations_corporation_id_standings) | **GET** /corporations/{corporation_id}/standings/ | Get corporation standings
*ESI::CorporationApi* | [**get_corporations_corporation_id_starbases**](docs/CorporationApi.md#get_corporations_corporation_id_starbases) | **GET** /corporations/{corporation_id}/starbases/ | Get corporation starbases (POSes)
*ESI::CorporationApi* | [**get_corporations_corporation_id_starbases_starbase_id**](docs/CorporationApi.md#get_corporations_corporation_id_starbases_starbase_id) | **GET** /corporations/{corporation_id}/starbases/{starbase_id}/ | Get starbase (POS) detail
*ESI::CorporationApi* | [**get_corporations_corporation_id_structures**](docs/CorporationApi.md#get_corporations_corporation_id_structures) | **GET** /corporations/{corporation_id}/structures/ | Get corporation structures
*ESI::CorporationApi* | [**get_corporations_corporation_id_titles**](docs/CorporationApi.md#get_corporations_corporation_id_titles) | **GET** /corporations/{corporation_id}/titles/ | Get corporation titles
*ESI::CorporationApi* | [**get_corporations_npccorps**](docs/CorporationApi.md#get_corporations_npccorps) | **GET** /corporations/npccorps/ | Get npc corporations
*ESI::DogmaApi* | [**get_dogma_attributes**](docs/DogmaApi.md#get_dogma_attributes) | **GET** /dogma/attributes/ | Get attributes
*ESI::DogmaApi* | [**get_dogma_attributes_attribute_id**](docs/DogmaApi.md#get_dogma_attributes_attribute_id) | **GET** /dogma/attributes/{attribute_id}/ | Get attribute information
*ESI::DogmaApi* | [**get_dogma_dynamic_items_type_id_item_id**](docs/DogmaApi.md#get_dogma_dynamic_items_type_id_item_id) | **GET** /dogma/dynamic/items/{type_id}/{item_id}/ | Get dynamic item information
*ESI::DogmaApi* | [**get_dogma_effects**](docs/DogmaApi.md#get_dogma_effects) | **GET** /dogma/effects/ | Get effects
*ESI::DogmaApi* | [**get_dogma_effects_effect_id**](docs/DogmaApi.md#get_dogma_effects_effect_id) | **GET** /dogma/effects/{effect_id}/ | Get effect information
*ESI::FactionWarfareApi* | [**get_characters_character_id_fw_stats**](docs/FactionWarfareApi.md#get_characters_character_id_fw_stats) | **GET** /characters/{character_id}/fw/stats/ | Overview of a character involved in faction warfare
*ESI::FactionWarfareApi* | [**get_corporations_corporation_id_fw_stats**](docs/FactionWarfareApi.md#get_corporations_corporation_id_fw_stats) | **GET** /corporations/{corporation_id}/fw/stats/ | Overview of a corporation involved in faction warfare
*ESI::FactionWarfareApi* | [**get_fw_leaderboards**](docs/FactionWarfareApi.md#get_fw_leaderboards) | **GET** /fw/leaderboards/ | List of the top factions in faction warfare
*ESI::FactionWarfareApi* | [**get_fw_leaderboards_characters**](docs/FactionWarfareApi.md#get_fw_leaderboards_characters) | **GET** /fw/leaderboards/characters/ | List of the top pilots in faction warfare
*ESI::FactionWarfareApi* | [**get_fw_leaderboards_corporations**](docs/FactionWarfareApi.md#get_fw_leaderboards_corporations) | **GET** /fw/leaderboards/corporations/ | List of the top corporations in faction warfare
*ESI::FactionWarfareApi* | [**get_fw_stats**](docs/FactionWarfareApi.md#get_fw_stats) | **GET** /fw/stats/ | An overview of statistics about factions involved in faction warfare
*ESI::FactionWarfareApi* | [**get_fw_systems**](docs/FactionWarfareApi.md#get_fw_systems) | **GET** /fw/systems/ | Ownership of faction warfare systems
*ESI::FactionWarfareApi* | [**get_fw_wars**](docs/FactionWarfareApi.md#get_fw_wars) | **GET** /fw/wars/ | Data about which NPC factions are at war
*ESI::FittingsApi* | [**delete_characters_character_id_fittings_fitting_id**](docs/FittingsApi.md#delete_characters_character_id_fittings_fitting_id) | **DELETE** /characters/{character_id}/fittings/{fitting_id}/ | Delete fitting
*ESI::FittingsApi* | [**get_characters_character_id_fittings**](docs/FittingsApi.md#get_characters_character_id_fittings) | **GET** /characters/{character_id}/fittings/ | Get fittings
*ESI::FittingsApi* | [**post_characters_character_id_fittings**](docs/FittingsApi.md#post_characters_character_id_fittings) | **POST** /characters/{character_id}/fittings/ | Create fitting
*ESI::FleetsApi* | [**delete_fleets_fleet_id_members_member_id**](docs/FleetsApi.md#delete_fleets_fleet_id_members_member_id) | **DELETE** /fleets/{fleet_id}/members/{member_id}/ | Kick fleet member
*ESI::FleetsApi* | [**delete_fleets_fleet_id_squads_squad_id**](docs/FleetsApi.md#delete_fleets_fleet_id_squads_squad_id) | **DELETE** /fleets/{fleet_id}/squads/{squad_id}/ | Delete fleet squad
*ESI::FleetsApi* | [**delete_fleets_fleet_id_wings_wing_id**](docs/FleetsApi.md#delete_fleets_fleet_id_wings_wing_id) | **DELETE** /fleets/{fleet_id}/wings/{wing_id}/ | Delete fleet wing
*ESI::FleetsApi* | [**get_characters_character_id_fleet**](docs/FleetsApi.md#get_characters_character_id_fleet) | **GET** /characters/{character_id}/fleet/ | Get character fleet info
*ESI::FleetsApi* | [**get_fleets_fleet_id**](docs/FleetsApi.md#get_fleets_fleet_id) | **GET** /fleets/{fleet_id}/ | Get fleet information
*ESI::FleetsApi* | [**get_fleets_fleet_id_members**](docs/FleetsApi.md#get_fleets_fleet_id_members) | **GET** /fleets/{fleet_id}/members/ | Get fleet members
*ESI::FleetsApi* | [**get_fleets_fleet_id_wings**](docs/FleetsApi.md#get_fleets_fleet_id_wings) | **GET** /fleets/{fleet_id}/wings/ | Get fleet wings
*ESI::FleetsApi* | [**post_fleets_fleet_id_members**](docs/FleetsApi.md#post_fleets_fleet_id_members) | **POST** /fleets/{fleet_id}/members/ | Create fleet invitation
*ESI::FleetsApi* | [**post_fleets_fleet_id_wings**](docs/FleetsApi.md#post_fleets_fleet_id_wings) | **POST** /fleets/{fleet_id}/wings/ | Create fleet wing
*ESI::FleetsApi* | [**post_fleets_fleet_id_wings_wing_id_squads**](docs/FleetsApi.md#post_fleets_fleet_id_wings_wing_id_squads) | **POST** /fleets/{fleet_id}/wings/{wing_id}/squads/ | Create fleet squad
*ESI::FleetsApi* | [**put_fleets_fleet_id**](docs/FleetsApi.md#put_fleets_fleet_id) | **PUT** /fleets/{fleet_id}/ | Update fleet
*ESI::FleetsApi* | [**put_fleets_fleet_id_members_member_id**](docs/FleetsApi.md#put_fleets_fleet_id_members_member_id) | **PUT** /fleets/{fleet_id}/members/{member_id}/ | Move fleet member
*ESI::FleetsApi* | [**put_fleets_fleet_id_squads_squad_id**](docs/FleetsApi.md#put_fleets_fleet_id_squads_squad_id) | **PUT** /fleets/{fleet_id}/squads/{squad_id}/ | Rename fleet squad
*ESI::FleetsApi* | [**put_fleets_fleet_id_wings_wing_id**](docs/FleetsApi.md#put_fleets_fleet_id_wings_wing_id) | **PUT** /fleets/{fleet_id}/wings/{wing_id}/ | Rename fleet wing
*ESI::IncursionsApi* | [**get_incursions**](docs/IncursionsApi.md#get_incursions) | **GET** /incursions/ | List incursions
*ESI::IndustryApi* | [**get_characters_character_id_industry_jobs**](docs/IndustryApi.md#get_characters_character_id_industry_jobs) | **GET** /characters/{character_id}/industry/jobs/ | List character industry jobs
*ESI::IndustryApi* | [**get_characters_character_id_mining**](docs/IndustryApi.md#get_characters_character_id_mining) | **GET** /characters/{character_id}/mining/ | Character mining ledger
*ESI::IndustryApi* | [**get_corporation_corporation_id_mining_extractions**](docs/IndustryApi.md#get_corporation_corporation_id_mining_extractions) | **GET** /corporation/{corporation_id}/mining/extractions/ | Moon extraction timers
*ESI::IndustryApi* | [**get_corporation_corporation_id_mining_observers**](docs/IndustryApi.md#get_corporation_corporation_id_mining_observers) | **GET** /corporation/{corporation_id}/mining/observers/ | Corporation mining observers
*ESI::IndustryApi* | [**get_corporation_corporation_id_mining_observers_observer_id**](docs/IndustryApi.md#get_corporation_corporation_id_mining_observers_observer_id) | **GET** /corporation/{corporation_id}/mining/observers/{observer_id}/ | Observed corporation mining
*ESI::IndustryApi* | [**get_corporations_corporation_id_industry_jobs**](docs/IndustryApi.md#get_corporations_corporation_id_industry_jobs) | **GET** /corporations/{corporation_id}/industry/jobs/ | List corporation industry jobs
*ESI::IndustryApi* | [**get_industry_facilities**](docs/IndustryApi.md#get_industry_facilities) | **GET** /industry/facilities/ | List industry facilities
*ESI::IndustryApi* | [**get_industry_systems**](docs/IndustryApi.md#get_industry_systems) | **GET** /industry/systems/ | List solar system cost indices
*ESI::InsuranceApi* | [**get_insurance_prices**](docs/InsuranceApi.md#get_insurance_prices) | **GET** /insurance/prices/ | List insurance levels
*ESI::KillmailsApi* | [**get_characters_character_id_killmails_recent**](docs/KillmailsApi.md#get_characters_character_id_killmails_recent) | **GET** /characters/{character_id}/killmails/recent/ | Get a character's recent kills and losses
*ESI::KillmailsApi* | [**get_corporations_corporation_id_killmails_recent**](docs/KillmailsApi.md#get_corporations_corporation_id_killmails_recent) | **GET** /corporations/{corporation_id}/killmails/recent/ | Get a corporation's recent kills and losses
*ESI::KillmailsApi* | [**get_killmails_killmail_id_killmail_hash**](docs/KillmailsApi.md#get_killmails_killmail_id_killmail_hash) | **GET** /killmails/{killmail_id}/{killmail_hash}/ | Get a single killmail
*ESI::LocationApi* | [**get_characters_character_id_location**](docs/LocationApi.md#get_characters_character_id_location) | **GET** /characters/{character_id}/location/ | Get character location
*ESI::LocationApi* | [**get_characters_character_id_online**](docs/LocationApi.md#get_characters_character_id_online) | **GET** /characters/{character_id}/online/ | Get character online
*ESI::LocationApi* | [**get_characters_character_id_ship**](docs/LocationApi.md#get_characters_character_id_ship) | **GET** /characters/{character_id}/ship/ | Get current ship
*ESI::LoyaltyApi* | [**get_characters_character_id_loyalty_points**](docs/LoyaltyApi.md#get_characters_character_id_loyalty_points) | **GET** /characters/{character_id}/loyalty/points/ | Get loyalty points
*ESI::LoyaltyApi* | [**get_loyalty_stores_corporation_id_offers**](docs/LoyaltyApi.md#get_loyalty_stores_corporation_id_offers) | **GET** /loyalty/stores/{corporation_id}/offers/ | List loyalty store offers
*ESI::MailApi* | [**delete_characters_character_id_mail_labels_label_id**](docs/MailApi.md#delete_characters_character_id_mail_labels_label_id) | **DELETE** /characters/{character_id}/mail/labels/{label_id}/ | Delete a mail label
*ESI::MailApi* | [**delete_characters_character_id_mail_mail_id**](docs/MailApi.md#delete_characters_character_id_mail_mail_id) | **DELETE** /characters/{character_id}/mail/{mail_id}/ | Delete a mail
*ESI::MailApi* | [**get_characters_character_id_mail**](docs/MailApi.md#get_characters_character_id_mail) | **GET** /characters/{character_id}/mail/ | Return mail headers
*ESI::MailApi* | [**get_characters_character_id_mail_labels**](docs/MailApi.md#get_characters_character_id_mail_labels) | **GET** /characters/{character_id}/mail/labels/ | Get mail labels and unread counts
*ESI::MailApi* | [**get_characters_character_id_mail_lists**](docs/MailApi.md#get_characters_character_id_mail_lists) | **GET** /characters/{character_id}/mail/lists/ | Return mailing list subscriptions
*ESI::MailApi* | [**get_characters_character_id_mail_mail_id**](docs/MailApi.md#get_characters_character_id_mail_mail_id) | **GET** /characters/{character_id}/mail/{mail_id}/ | Return a mail
*ESI::MailApi* | [**post_characters_character_id_mail**](docs/MailApi.md#post_characters_character_id_mail) | **POST** /characters/{character_id}/mail/ | Send a new mail
*ESI::MailApi* | [**post_characters_character_id_mail_labels**](docs/MailApi.md#post_characters_character_id_mail_labels) | **POST** /characters/{character_id}/mail/labels/ | Create a mail label
*ESI::MailApi* | [**put_characters_character_id_mail_mail_id**](docs/MailApi.md#put_characters_character_id_mail_mail_id) | **PUT** /characters/{character_id}/mail/{mail_id}/ | Update metadata about a mail
*ESI::MarketApi* | [**get_characters_character_id_orders**](docs/MarketApi.md#get_characters_character_id_orders) | **GET** /characters/{character_id}/orders/ | List open orders from a character
*ESI::MarketApi* | [**get_characters_character_id_orders_history**](docs/MarketApi.md#get_characters_character_id_orders_history) | **GET** /characters/{character_id}/orders/history/ | List historical orders by a character
*ESI::MarketApi* | [**get_corporations_corporation_id_orders**](docs/MarketApi.md#get_corporations_corporation_id_orders) | **GET** /corporations/{corporation_id}/orders/ | List open orders from a corporation
*ESI::MarketApi* | [**get_corporations_corporation_id_orders_history**](docs/MarketApi.md#get_corporations_corporation_id_orders_history) | **GET** /corporations/{corporation_id}/orders/history/ | List historical orders from a corporation
*ESI::MarketApi* | [**get_markets_groups**](docs/MarketApi.md#get_markets_groups) | **GET** /markets/groups/ | Get item groups
*ESI::MarketApi* | [**get_markets_groups_market_group_id**](docs/MarketApi.md#get_markets_groups_market_group_id) | **GET** /markets/groups/{market_group_id}/ | Get item group information
*ESI::MarketApi* | [**get_markets_prices**](docs/MarketApi.md#get_markets_prices) | **GET** /markets/prices/ | List market prices
*ESI::MarketApi* | [**get_markets_region_id_history**](docs/MarketApi.md#get_markets_region_id_history) | **GET** /markets/{region_id}/history/ | List historical market statistics in a region
*ESI::MarketApi* | [**get_markets_region_id_orders**](docs/MarketApi.md#get_markets_region_id_orders) | **GET** /markets/{region_id}/orders/ | List orders in a region
*ESI::MarketApi* | [**get_markets_region_id_types**](docs/MarketApi.md#get_markets_region_id_types) | **GET** /markets/{region_id}/types/ | List type IDs relevant to a market
*ESI::MarketApi* | [**get_markets_structures_structure_id**](docs/MarketApi.md#get_markets_structures_structure_id) | **GET** /markets/structures/{structure_id}/ | List orders in a structure
*ESI::OpportunitiesApi* | [**get_characters_character_id_opportunities**](docs/OpportunitiesApi.md#get_characters_character_id_opportunities) | **GET** /characters/{character_id}/opportunities/ | Get a character's completed tasks
*ESI::OpportunitiesApi* | [**get_opportunities_groups**](docs/OpportunitiesApi.md#get_opportunities_groups) | **GET** /opportunities/groups/ | Get opportunities groups
*ESI::OpportunitiesApi* | [**get_opportunities_groups_group_id**](docs/OpportunitiesApi.md#get_opportunities_groups_group_id) | **GET** /opportunities/groups/{group_id}/ | Get opportunities group
*ESI::OpportunitiesApi* | [**get_opportunities_tasks**](docs/OpportunitiesApi.md#get_opportunities_tasks) | **GET** /opportunities/tasks/ | Get opportunities tasks
*ESI::OpportunitiesApi* | [**get_opportunities_tasks_task_id**](docs/OpportunitiesApi.md#get_opportunities_tasks_task_id) | **GET** /opportunities/tasks/{task_id}/ | Get opportunities task
*ESI::PlanetaryInteractionApi* | [**get_characters_character_id_planets**](docs/PlanetaryInteractionApi.md#get_characters_character_id_planets) | **GET** /characters/{character_id}/planets/ | Get colonies
*ESI::PlanetaryInteractionApi* | [**get_characters_character_id_planets_planet_id**](docs/PlanetaryInteractionApi.md#get_characters_character_id_planets_planet_id) | **GET** /characters/{character_id}/planets/{planet_id}/ | Get colony layout
*ESI::PlanetaryInteractionApi* | [**get_corporations_corporation_id_customs_offices**](docs/PlanetaryInteractionApi.md#get_corporations_corporation_id_customs_offices) | **GET** /corporations/{corporation_id}/customs_offices/ | List corporation customs offices
*ESI::PlanetaryInteractionApi* | [**get_universe_schematics_schematic_id**](docs/PlanetaryInteractionApi.md#get_universe_schematics_schematic_id) | **GET** /universe/schematics/{schematic_id}/ | Get schematic information
*ESI::RoutesApi* | [**get_route_origin_destination**](docs/RoutesApi.md#get_route_origin_destination) | **GET** /route/{origin}/{destination}/ | Get route
*ESI::SearchApi* | [**get_characters_character_id_search**](docs/SearchApi.md#get_characters_character_id_search) | **GET** /characters/{character_id}/search/ | Search on a string
*ESI::SearchApi* | [**get_search**](docs/SearchApi.md#get_search) | **GET** /search/ | Search on a string
*ESI::SkillsApi* | [**get_characters_character_id_attributes**](docs/SkillsApi.md#get_characters_character_id_attributes) | **GET** /characters/{character_id}/attributes/ | Get character attributes
*ESI::SkillsApi* | [**get_characters_character_id_skillqueue**](docs/SkillsApi.md#get_characters_character_id_skillqueue) | **GET** /characters/{character_id}/skillqueue/ | Get character's skill queue
*ESI::SkillsApi* | [**get_characters_character_id_skills**](docs/SkillsApi.md#get_characters_character_id_skills) | **GET** /characters/{character_id}/skills/ | Get character skills
*ESI::SovereigntyApi* | [**get_sovereignty_campaigns**](docs/SovereigntyApi.md#get_sovereignty_campaigns) | **GET** /sovereignty/campaigns/ | List sovereignty campaigns
*ESI::SovereigntyApi* | [**get_sovereignty_map**](docs/SovereigntyApi.md#get_sovereignty_map) | **GET** /sovereignty/map/ | List sovereignty of systems
*ESI::SovereigntyApi* | [**get_sovereignty_structures**](docs/SovereigntyApi.md#get_sovereignty_structures) | **GET** /sovereignty/structures/ | List sovereignty structures
*ESI::StatusApi* | [**get_status**](docs/StatusApi.md#get_status) | **GET** /status/ | Retrieve the uptime and player counts
*ESI::UniverseApi* | [**get_universe_ancestries**](docs/UniverseApi.md#get_universe_ancestries) | **GET** /universe/ancestries/ | Get ancestries
*ESI::UniverseApi* | [**get_universe_asteroid_belts_asteroid_belt_id**](docs/UniverseApi.md#get_universe_asteroid_belts_asteroid_belt_id) | **GET** /universe/asteroid_belts/{asteroid_belt_id}/ | Get asteroid belt information
*ESI::UniverseApi* | [**get_universe_bloodlines**](docs/UniverseApi.md#get_universe_bloodlines) | **GET** /universe/bloodlines/ | Get bloodlines
*ESI::UniverseApi* | [**get_universe_categories**](docs/UniverseApi.md#get_universe_categories) | **GET** /universe/categories/ | Get item categories
*ESI::UniverseApi* | [**get_universe_categories_category_id**](docs/UniverseApi.md#get_universe_categories_category_id) | **GET** /universe/categories/{category_id}/ | Get item category information
*ESI::UniverseApi* | [**get_universe_constellations**](docs/UniverseApi.md#get_universe_constellations) | **GET** /universe/constellations/ | Get constellations
*ESI::UniverseApi* | [**get_universe_constellations_constellation_id**](docs/UniverseApi.md#get_universe_constellations_constellation_id) | **GET** /universe/constellations/{constellation_id}/ | Get constellation information
*ESI::UniverseApi* | [**get_universe_factions**](docs/UniverseApi.md#get_universe_factions) | **GET** /universe/factions/ | Get factions
*ESI::UniverseApi* | [**get_universe_graphics**](docs/UniverseApi.md#get_universe_graphics) | **GET** /universe/graphics/ | Get graphics
*ESI::UniverseApi* | [**get_universe_graphics_graphic_id**](docs/UniverseApi.md#get_universe_graphics_graphic_id) | **GET** /universe/graphics/{graphic_id}/ | Get graphic information
*ESI::UniverseApi* | [**get_universe_groups**](docs/UniverseApi.md#get_universe_groups) | **GET** /universe/groups/ | Get item groups
*ESI::UniverseApi* | [**get_universe_groups_group_id**](docs/UniverseApi.md#get_universe_groups_group_id) | **GET** /universe/groups/{group_id}/ | Get item group information
*ESI::UniverseApi* | [**get_universe_moons_moon_id**](docs/UniverseApi.md#get_universe_moons_moon_id) | **GET** /universe/moons/{moon_id}/ | Get moon information
*ESI::UniverseApi* | [**get_universe_planets_planet_id**](docs/UniverseApi.md#get_universe_planets_planet_id) | **GET** /universe/planets/{planet_id}/ | Get planet information
*ESI::UniverseApi* | [**get_universe_races**](docs/UniverseApi.md#get_universe_races) | **GET** /universe/races/ | Get character races
*ESI::UniverseApi* | [**get_universe_regions**](docs/UniverseApi.md#get_universe_regions) | **GET** /universe/regions/ | Get regions
*ESI::UniverseApi* | [**get_universe_regions_region_id**](docs/UniverseApi.md#get_universe_regions_region_id) | **GET** /universe/regions/{region_id}/ | Get region information
*ESI::UniverseApi* | [**get_universe_stargates_stargate_id**](docs/UniverseApi.md#get_universe_stargates_stargate_id) | **GET** /universe/stargates/{stargate_id}/ | Get stargate information
*ESI::UniverseApi* | [**get_universe_stars_star_id**](docs/UniverseApi.md#get_universe_stars_star_id) | **GET** /universe/stars/{star_id}/ | Get star information
*ESI::UniverseApi* | [**get_universe_stations_station_id**](docs/UniverseApi.md#get_universe_stations_station_id) | **GET** /universe/stations/{station_id}/ | Get station information
*ESI::UniverseApi* | [**get_universe_structures**](docs/UniverseApi.md#get_universe_structures) | **GET** /universe/structures/ | List all public structures
*ESI::UniverseApi* | [**get_universe_structures_structure_id**](docs/UniverseApi.md#get_universe_structures_structure_id) | **GET** /universe/structures/{structure_id}/ | Get structure information
*ESI::UniverseApi* | [**get_universe_system_jumps**](docs/UniverseApi.md#get_universe_system_jumps) | **GET** /universe/system_jumps/ | Get system jumps
*ESI::UniverseApi* | [**get_universe_system_kills**](docs/UniverseApi.md#get_universe_system_kills) | **GET** /universe/system_kills/ | Get system kills
*ESI::UniverseApi* | [**get_universe_systems**](docs/UniverseApi.md#get_universe_systems) | **GET** /universe/systems/ | Get solar systems
*ESI::UniverseApi* | [**get_universe_systems_system_id**](docs/UniverseApi.md#get_universe_systems_system_id) | **GET** /universe/systems/{system_id}/ | Get solar system information
*ESI::UniverseApi* | [**get_universe_types**](docs/UniverseApi.md#get_universe_types) | **GET** /universe/types/ | Get types
*ESI::UniverseApi* | [**get_universe_types_type_id**](docs/UniverseApi.md#get_universe_types_type_id) | **GET** /universe/types/{type_id}/ | Get type information
*ESI::UniverseApi* | [**post_universe_ids**](docs/UniverseApi.md#post_universe_ids) | **POST** /universe/ids/ | Bulk names to IDs
*ESI::UniverseApi* | [**post_universe_names**](docs/UniverseApi.md#post_universe_names) | **POST** /universe/names/ | Get names and categories for a set of IDs
*ESI::UserInterfaceApi* | [**post_ui_autopilot_waypoint**](docs/UserInterfaceApi.md#post_ui_autopilot_waypoint) | **POST** /ui/autopilot/waypoint/ | Set Autopilot Waypoint
*ESI::UserInterfaceApi* | [**post_ui_openwindow_contract**](docs/UserInterfaceApi.md#post_ui_openwindow_contract) | **POST** /ui/openwindow/contract/ | Open Contract Window
*ESI::UserInterfaceApi* | [**post_ui_openwindow_information**](docs/UserInterfaceApi.md#post_ui_openwindow_information) | **POST** /ui/openwindow/information/ | Open Information Window
*ESI::UserInterfaceApi* | [**post_ui_openwindow_marketdetails**](docs/UserInterfaceApi.md#post_ui_openwindow_marketdetails) | **POST** /ui/openwindow/marketdetails/ | Open Market Details
*ESI::UserInterfaceApi* | [**post_ui_openwindow_newmail**](docs/UserInterfaceApi.md#post_ui_openwindow_newmail) | **POST** /ui/openwindow/newmail/ | Open New Mail Window
*ESI::WalletApi* | [**get_characters_character_id_wallet**](docs/WalletApi.md#get_characters_character_id_wallet) | **GET** /characters/{character_id}/wallet/ | Get a character's wallet balance
*ESI::WalletApi* | [**get_characters_character_id_wallet_journal**](docs/WalletApi.md#get_characters_character_id_wallet_journal) | **GET** /characters/{character_id}/wallet/journal/ | Get character wallet journal
*ESI::WalletApi* | [**get_characters_character_id_wallet_transactions**](docs/WalletApi.md#get_characters_character_id_wallet_transactions) | **GET** /characters/{character_id}/wallet/transactions/ | Get wallet transactions
*ESI::WalletApi* | [**get_corporations_corporation_id_wallets**](docs/WalletApi.md#get_corporations_corporation_id_wallets) | **GET** /corporations/{corporation_id}/wallets/ | Returns a corporation's wallet balance
*ESI::WalletApi* | [**get_corporations_corporation_id_wallets_division_journal**](docs/WalletApi.md#get_corporations_corporation_id_wallets_division_journal) | **GET** /corporations/{corporation_id}/wallets/{division}/journal/ | Get corporation wallet journal
*ESI::WalletApi* | [**get_corporations_corporation_id_wallets_division_transactions**](docs/WalletApi.md#get_corporations_corporation_id_wallets_division_transactions) | **GET** /corporations/{corporation_id}/wallets/{division}/transactions/ | Get corporation wallet transactions
*ESI::WarsApi* | [**get_wars**](docs/WarsApi.md#get_wars) | **GET** /wars/ | List wars
*ESI::WarsApi* | [**get_wars_war_id**](docs/WarsApi.md#get_wars_war_id) | **GET** /wars/{war_id}/ | Get war information
*ESI::WarsApi* | [**get_wars_war_id_killmails**](docs/WarsApi.md#get_wars_war_id_killmails) | **GET** /wars/{war_id}/killmails/ | List kills for a war


## Documentation for Models

 - [ESI::BadRequest](docs/BadRequest.md)
 - [ESI::DeleteCharactersCharacterIdMailLabelsLabelIdUnprocessableEntity](docs/DeleteCharactersCharacterIdMailLabelsLabelIdUnprocessableEntity.md)
 - [ESI::DeleteFleetsFleetIdMembersMemberIdNotFound](docs/DeleteFleetsFleetIdMembersMemberIdNotFound.md)
 - [ESI::DeleteFleetsFleetIdSquadsSquadIdNotFound](docs/DeleteFleetsFleetIdSquadsSquadIdNotFound.md)
 - [ESI::DeleteFleetsFleetIdWingsWingIdNotFound](docs/DeleteFleetsFleetIdWingsWingIdNotFound.md)
 - [ESI::ErrorLimited](docs/ErrorLimited.md)
 - [ESI::Forbidden](docs/Forbidden.md)
 - [ESI::GatewayTimeout](docs/GatewayTimeout.md)
 - [ESI::GetAlliancesAllianceIdContacts200Ok](docs/GetAlliancesAllianceIdContacts200Ok.md)
 - [ESI::GetAlliancesAllianceIdContactsLabels200Ok](docs/GetAlliancesAllianceIdContactsLabels200Ok.md)
 - [ESI::GetAlliancesAllianceIdIconsNotFound](docs/GetAlliancesAllianceIdIconsNotFound.md)
 - [ESI::GetAlliancesAllianceIdIconsOk](docs/GetAlliancesAllianceIdIconsOk.md)
 - [ESI::GetAlliancesAllianceIdNotFound](docs/GetAlliancesAllianceIdNotFound.md)
 - [ESI::GetAlliancesAllianceIdOk](docs/GetAlliancesAllianceIdOk.md)
 - [ESI::GetCharactersCharacterIdAgentsResearch200Ok](docs/GetCharactersCharacterIdAgentsResearch200Ok.md)
 - [ESI::GetCharactersCharacterIdAssets200Ok](docs/GetCharactersCharacterIdAssets200Ok.md)
 - [ESI::GetCharactersCharacterIdAttributesOk](docs/GetCharactersCharacterIdAttributesOk.md)
 - [ESI::GetCharactersCharacterIdBlueprints200Ok](docs/GetCharactersCharacterIdBlueprints200Ok.md)
 - [ESI::GetCharactersCharacterIdBookmarks200Ok](docs/GetCharactersCharacterIdBookmarks200Ok.md)
 - [ESI::GetCharactersCharacterIdBookmarksCoordinates](docs/GetCharactersCharacterIdBookmarksCoordinates.md)
 - [ESI::GetCharactersCharacterIdBookmarksFolders200Ok](docs/GetCharactersCharacterIdBookmarksFolders200Ok.md)
 - [ESI::GetCharactersCharacterIdBookmarksItem](docs/GetCharactersCharacterIdBookmarksItem.md)
 - [ESI::GetCharactersCharacterIdCalendar200Ok](docs/GetCharactersCharacterIdCalendar200Ok.md)
 - [ESI::GetCharactersCharacterIdCalendarEventIdAttendees200Ok](docs/GetCharactersCharacterIdCalendarEventIdAttendees200Ok.md)
 - [ESI::GetCharactersCharacterIdCalendarEventIdAttendeesNotFound](docs/GetCharactersCharacterIdCalendarEventIdAttendeesNotFound.md)
 - [ESI::GetCharactersCharacterIdCalendarEventIdNotFound](docs/GetCharactersCharacterIdCalendarEventIdNotFound.md)
 - [ESI::GetCharactersCharacterIdCalendarEventIdOk](docs/GetCharactersCharacterIdCalendarEventIdOk.md)
 - [ESI::GetCharactersCharacterIdClonesHomeLocation](docs/GetCharactersCharacterIdClonesHomeLocation.md)
 - [ESI::GetCharactersCharacterIdClonesJumpClone](docs/GetCharactersCharacterIdClonesJumpClone.md)
 - [ESI::GetCharactersCharacterIdClonesOk](docs/GetCharactersCharacterIdClonesOk.md)
 - [ESI::GetCharactersCharacterIdContacts200Ok](docs/GetCharactersCharacterIdContacts200Ok.md)
 - [ESI::GetCharactersCharacterIdContactsLabels200Ok](docs/GetCharactersCharacterIdContactsLabels200Ok.md)
 - [ESI::GetCharactersCharacterIdContracts200Ok](docs/GetCharactersCharacterIdContracts200Ok.md)
 - [ESI::GetCharactersCharacterIdContractsContractIdBids200Ok](docs/GetCharactersCharacterIdContractsContractIdBids200Ok.md)
 - [ESI::GetCharactersCharacterIdContractsContractIdBidsNotFound](docs/GetCharactersCharacterIdContractsContractIdBidsNotFound.md)
 - [ESI::GetCharactersCharacterIdContractsContractIdItems200Ok](docs/GetCharactersCharacterIdContractsContractIdItems200Ok.md)
 - [ESI::GetCharactersCharacterIdContractsContractIdItemsNotFound](docs/GetCharactersCharacterIdContractsContractIdItemsNotFound.md)
 - [ESI::GetCharactersCharacterIdCorporationhistory200Ok](docs/GetCharactersCharacterIdCorporationhistory200Ok.md)
 - [ESI::GetCharactersCharacterIdFatigueOk](docs/GetCharactersCharacterIdFatigueOk.md)
 - [ESI::GetCharactersCharacterIdFittings200Ok](docs/GetCharactersCharacterIdFittings200Ok.md)
 - [ESI::GetCharactersCharacterIdFittingsItem](docs/GetCharactersCharacterIdFittingsItem.md)
 - [ESI::GetCharactersCharacterIdFleetNotFound](docs/GetCharactersCharacterIdFleetNotFound.md)
 - [ESI::GetCharactersCharacterIdFleetOk](docs/GetCharactersCharacterIdFleetOk.md)
 - [ESI::GetCharactersCharacterIdFwStatsKills](docs/GetCharactersCharacterIdFwStatsKills.md)
 - [ESI::GetCharactersCharacterIdFwStatsOk](docs/GetCharactersCharacterIdFwStatsOk.md)
 - [ESI::GetCharactersCharacterIdFwStatsVictoryPoints](docs/GetCharactersCharacterIdFwStatsVictoryPoints.md)
 - [ESI::GetCharactersCharacterIdIndustryJobs200Ok](docs/GetCharactersCharacterIdIndustryJobs200Ok.md)
 - [ESI::GetCharactersCharacterIdKillmailsRecent200Ok](docs/GetCharactersCharacterIdKillmailsRecent200Ok.md)
 - [ESI::GetCharactersCharacterIdLocationOk](docs/GetCharactersCharacterIdLocationOk.md)
 - [ESI::GetCharactersCharacterIdLoyaltyPoints200Ok](docs/GetCharactersCharacterIdLoyaltyPoints200Ok.md)
 - [ESI::GetCharactersCharacterIdMail200Ok](docs/GetCharactersCharacterIdMail200Ok.md)
 - [ESI::GetCharactersCharacterIdMailLabelsLabel](docs/GetCharactersCharacterIdMailLabelsLabel.md)
 - [ESI::GetCharactersCharacterIdMailLabelsOk](docs/GetCharactersCharacterIdMailLabelsOk.md)
 - [ESI::GetCharactersCharacterIdMailLists200Ok](docs/GetCharactersCharacterIdMailLists200Ok.md)
 - [ESI::GetCharactersCharacterIdMailMailIdNotFound](docs/GetCharactersCharacterIdMailMailIdNotFound.md)
 - [ESI::GetCharactersCharacterIdMailMailIdOk](docs/GetCharactersCharacterIdMailMailIdOk.md)
 - [ESI::GetCharactersCharacterIdMailMailIdRecipient](docs/GetCharactersCharacterIdMailMailIdRecipient.md)
 - [ESI::GetCharactersCharacterIdMailRecipient](docs/GetCharactersCharacterIdMailRecipient.md)
 - [ESI::GetCharactersCharacterIdMedals200Ok](docs/GetCharactersCharacterIdMedals200Ok.md)
 - [ESI::GetCharactersCharacterIdMedalsGraphic](docs/GetCharactersCharacterIdMedalsGraphic.md)
 - [ESI::GetCharactersCharacterIdMining200Ok](docs/GetCharactersCharacterIdMining200Ok.md)
 - [ESI::GetCharactersCharacterIdNotFound](docs/GetCharactersCharacterIdNotFound.md)
 - [ESI::GetCharactersCharacterIdNotifications200Ok](docs/GetCharactersCharacterIdNotifications200Ok.md)
 - [ESI::GetCharactersCharacterIdNotificationsContacts200Ok](docs/GetCharactersCharacterIdNotificationsContacts200Ok.md)
 - [ESI::GetCharactersCharacterIdOk](docs/GetCharactersCharacterIdOk.md)
 - [ESI::GetCharactersCharacterIdOnlineOk](docs/GetCharactersCharacterIdOnlineOk.md)
 - [ESI::GetCharactersCharacterIdOpportunities200Ok](docs/GetCharactersCharacterIdOpportunities200Ok.md)
 - [ESI::GetCharactersCharacterIdOrders200Ok](docs/GetCharactersCharacterIdOrders200Ok.md)
 - [ESI::GetCharactersCharacterIdOrdersHistory200Ok](docs/GetCharactersCharacterIdOrdersHistory200Ok.md)
 - [ESI::GetCharactersCharacterIdPlanets200Ok](docs/GetCharactersCharacterIdPlanets200Ok.md)
 - [ESI::GetCharactersCharacterIdPlanetsPlanetIdContent](docs/GetCharactersCharacterIdPlanetsPlanetIdContent.md)
 - [ESI::GetCharactersCharacterIdPlanetsPlanetIdExtractorDetails](docs/GetCharactersCharacterIdPlanetsPlanetIdExtractorDetails.md)
 - [ESI::GetCharactersCharacterIdPlanetsPlanetIdFactoryDetails](docs/GetCharactersCharacterIdPlanetsPlanetIdFactoryDetails.md)
 - [ESI::GetCharactersCharacterIdPlanetsPlanetIdHead](docs/GetCharactersCharacterIdPlanetsPlanetIdHead.md)
 - [ESI::GetCharactersCharacterIdPlanetsPlanetIdLink](docs/GetCharactersCharacterIdPlanetsPlanetIdLink.md)
 - [ESI::GetCharactersCharacterIdPlanetsPlanetIdNotFound](docs/GetCharactersCharacterIdPlanetsPlanetIdNotFound.md)
 - [ESI::GetCharactersCharacterIdPlanetsPlanetIdOk](docs/GetCharactersCharacterIdPlanetsPlanetIdOk.md)
 - [ESI::GetCharactersCharacterIdPlanetsPlanetIdPin](docs/GetCharactersCharacterIdPlanetsPlanetIdPin.md)
 - [ESI::GetCharactersCharacterIdPlanetsPlanetIdRoute](docs/GetCharactersCharacterIdPlanetsPlanetIdRoute.md)
 - [ESI::GetCharactersCharacterIdPortraitNotFound](docs/GetCharactersCharacterIdPortraitNotFound.md)
 - [ESI::GetCharactersCharacterIdPortraitOk](docs/GetCharactersCharacterIdPortraitOk.md)
 - [ESI::GetCharactersCharacterIdRolesOk](docs/GetCharactersCharacterIdRolesOk.md)
 - [ESI::GetCharactersCharacterIdSearchOk](docs/GetCharactersCharacterIdSearchOk.md)
 - [ESI::GetCharactersCharacterIdShipOk](docs/GetCharactersCharacterIdShipOk.md)
 - [ESI::GetCharactersCharacterIdSkillqueue200Ok](docs/GetCharactersCharacterIdSkillqueue200Ok.md)
 - [ESI::GetCharactersCharacterIdSkillsOk](docs/GetCharactersCharacterIdSkillsOk.md)
 - [ESI::GetCharactersCharacterIdSkillsSkill](docs/GetCharactersCharacterIdSkillsSkill.md)
 - [ESI::GetCharactersCharacterIdStandings200Ok](docs/GetCharactersCharacterIdStandings200Ok.md)
 - [ESI::GetCharactersCharacterIdStats200Ok](docs/GetCharactersCharacterIdStats200Ok.md)
 - [ESI::GetCharactersCharacterIdStatsCharacter](docs/GetCharactersCharacterIdStatsCharacter.md)
 - [ESI::GetCharactersCharacterIdStatsCombat](docs/GetCharactersCharacterIdStatsCombat.md)
 - [ESI::GetCharactersCharacterIdStatsIndustry](docs/GetCharactersCharacterIdStatsIndustry.md)
 - [ESI::GetCharactersCharacterIdStatsInventory](docs/GetCharactersCharacterIdStatsInventory.md)
 - [ESI::GetCharactersCharacterIdStatsIsk](docs/GetCharactersCharacterIdStatsIsk.md)
 - [ESI::GetCharactersCharacterIdStatsMarket](docs/GetCharactersCharacterIdStatsMarket.md)
 - [ESI::GetCharactersCharacterIdStatsMining](docs/GetCharactersCharacterIdStatsMining.md)
 - [ESI::GetCharactersCharacterIdStatsModule](docs/GetCharactersCharacterIdStatsModule.md)
 - [ESI::GetCharactersCharacterIdStatsOrbital](docs/GetCharactersCharacterIdStatsOrbital.md)
 - [ESI::GetCharactersCharacterIdStatsPve](docs/GetCharactersCharacterIdStatsPve.md)
 - [ESI::GetCharactersCharacterIdStatsSocial](docs/GetCharactersCharacterIdStatsSocial.md)
 - [ESI::GetCharactersCharacterIdStatsTravel](docs/GetCharactersCharacterIdStatsTravel.md)
 - [ESI::GetCharactersCharacterIdTitles200Ok](docs/GetCharactersCharacterIdTitles200Ok.md)
 - [ESI::GetCharactersCharacterIdWalletJournal200Ok](docs/GetCharactersCharacterIdWalletJournal200Ok.md)
 - [ESI::GetCharactersCharacterIdWalletTransactions200Ok](docs/GetCharactersCharacterIdWalletTransactions200Ok.md)
 - [ESI::GetContractsPublicBidsContractId200Ok](docs/GetContractsPublicBidsContractId200Ok.md)
 - [ESI::GetContractsPublicBidsContractIdForbidden](docs/GetContractsPublicBidsContractIdForbidden.md)
 - [ESI::GetContractsPublicBidsContractIdNotFound](docs/GetContractsPublicBidsContractIdNotFound.md)
 - [ESI::GetContractsPublicItemsContractId200Ok](docs/GetContractsPublicItemsContractId200Ok.md)
 - [ESI::GetContractsPublicItemsContractIdForbidden](docs/GetContractsPublicItemsContractIdForbidden.md)
 - [ESI::GetContractsPublicItemsContractIdNotFound](docs/GetContractsPublicItemsContractIdNotFound.md)
 - [ESI::GetContractsPublicRegionId200Ok](docs/GetContractsPublicRegionId200Ok.md)
 - [ESI::GetContractsPublicRegionIdNotFound](docs/GetContractsPublicRegionIdNotFound.md)
 - [ESI::GetCorporationCorporationIdMiningExtractions200Ok](docs/GetCorporationCorporationIdMiningExtractions200Ok.md)
 - [ESI::GetCorporationCorporationIdMiningObservers200Ok](docs/GetCorporationCorporationIdMiningObservers200Ok.md)
 - [ESI::GetCorporationCorporationIdMiningObserversObserverId200Ok](docs/GetCorporationCorporationIdMiningObserversObserverId200Ok.md)
 - [ESI::GetCorporationsCorporationIdAlliancehistory200Ok](docs/GetCorporationsCorporationIdAlliancehistory200Ok.md)
 - [ESI::GetCorporationsCorporationIdAssets200Ok](docs/GetCorporationsCorporationIdAssets200Ok.md)
 - [ESI::GetCorporationsCorporationIdBlueprints200Ok](docs/GetCorporationsCorporationIdBlueprints200Ok.md)
 - [ESI::GetCorporationsCorporationIdBookmarks200Ok](docs/GetCorporationsCorporationIdBookmarks200Ok.md)
 - [ESI::GetCorporationsCorporationIdBookmarksCoordinates](docs/GetCorporationsCorporationIdBookmarksCoordinates.md)
 - [ESI::GetCorporationsCorporationIdBookmarksFolders200Ok](docs/GetCorporationsCorporationIdBookmarksFolders200Ok.md)
 - [ESI::GetCorporationsCorporationIdBookmarksItem](docs/GetCorporationsCorporationIdBookmarksItem.md)
 - [ESI::GetCorporationsCorporationIdContacts200Ok](docs/GetCorporationsCorporationIdContacts200Ok.md)
 - [ESI::GetCorporationsCorporationIdContactsLabels200Ok](docs/GetCorporationsCorporationIdContactsLabels200Ok.md)
 - [ESI::GetCorporationsCorporationIdContainersLogs200Ok](docs/GetCorporationsCorporationIdContainersLogs200Ok.md)
 - [ESI::GetCorporationsCorporationIdContracts200Ok](docs/GetCorporationsCorporationIdContracts200Ok.md)
 - [ESI::GetCorporationsCorporationIdContractsContractIdBids200Ok](docs/GetCorporationsCorporationIdContractsContractIdBids200Ok.md)
 - [ESI::GetCorporationsCorporationIdContractsContractIdBidsNotFound](docs/GetCorporationsCorporationIdContractsContractIdBidsNotFound.md)
 - [ESI::GetCorporationsCorporationIdContractsContractIdItems200Ok](docs/GetCorporationsCorporationIdContractsContractIdItems200Ok.md)
 - [ESI::GetCorporationsCorporationIdContractsContractIdItemsError520](docs/GetCorporationsCorporationIdContractsContractIdItemsError520.md)
 - [ESI::GetCorporationsCorporationIdContractsContractIdItemsNotFound](docs/GetCorporationsCorporationIdContractsContractIdItemsNotFound.md)
 - [ESI::GetCorporationsCorporationIdCustomsOffices200Ok](docs/GetCorporationsCorporationIdCustomsOffices200Ok.md)
 - [ESI::GetCorporationsCorporationIdDivisionsHangarHangar](docs/GetCorporationsCorporationIdDivisionsHangarHangar.md)
 - [ESI::GetCorporationsCorporationIdDivisionsOk](docs/GetCorporationsCorporationIdDivisionsOk.md)
 - [ESI::GetCorporationsCorporationIdDivisionsWalletWallet](docs/GetCorporationsCorporationIdDivisionsWalletWallet.md)
 - [ESI::GetCorporationsCorporationIdFacilities200Ok](docs/GetCorporationsCorporationIdFacilities200Ok.md)
 - [ESI::GetCorporationsCorporationIdFwStatsKills](docs/GetCorporationsCorporationIdFwStatsKills.md)
 - [ESI::GetCorporationsCorporationIdFwStatsOk](docs/GetCorporationsCorporationIdFwStatsOk.md)
 - [ESI::GetCorporationsCorporationIdFwStatsVictoryPoints](docs/GetCorporationsCorporationIdFwStatsVictoryPoints.md)
 - [ESI::GetCorporationsCorporationIdIconsNotFound](docs/GetCorporationsCorporationIdIconsNotFound.md)
 - [ESI::GetCorporationsCorporationIdIconsOk](docs/GetCorporationsCorporationIdIconsOk.md)
 - [ESI::GetCorporationsCorporationIdIndustryJobs200Ok](docs/GetCorporationsCorporationIdIndustryJobs200Ok.md)
 - [ESI::GetCorporationsCorporationIdKillmailsRecent200Ok](docs/GetCorporationsCorporationIdKillmailsRecent200Ok.md)
 - [ESI::GetCorporationsCorporationIdMedals200Ok](docs/GetCorporationsCorporationIdMedals200Ok.md)
 - [ESI::GetCorporationsCorporationIdMedalsIssued200Ok](docs/GetCorporationsCorporationIdMedalsIssued200Ok.md)
 - [ESI::GetCorporationsCorporationIdMembersTitles200Ok](docs/GetCorporationsCorporationIdMembersTitles200Ok.md)
 - [ESI::GetCorporationsCorporationIdMembertracking200Ok](docs/GetCorporationsCorporationIdMembertracking200Ok.md)
 - [ESI::GetCorporationsCorporationIdNotFound](docs/GetCorporationsCorporationIdNotFound.md)
 - [ESI::GetCorporationsCorporationIdOk](docs/GetCorporationsCorporationIdOk.md)
 - [ESI::GetCorporationsCorporationIdOrders200Ok](docs/GetCorporationsCorporationIdOrders200Ok.md)
 - [ESI::GetCorporationsCorporationIdOrdersHistory200Ok](docs/GetCorporationsCorporationIdOrdersHistory200Ok.md)
 - [ESI::GetCorporationsCorporationIdRoles200Ok](docs/GetCorporationsCorporationIdRoles200Ok.md)
 - [ESI::GetCorporationsCorporationIdRolesHistory200Ok](docs/GetCorporationsCorporationIdRolesHistory200Ok.md)
 - [ESI::GetCorporationsCorporationIdShareholders200Ok](docs/GetCorporationsCorporationIdShareholders200Ok.md)
 - [ESI::GetCorporationsCorporationIdStandings200Ok](docs/GetCorporationsCorporationIdStandings200Ok.md)
 - [ESI::GetCorporationsCorporationIdStarbases200Ok](docs/GetCorporationsCorporationIdStarbases200Ok.md)
 - [ESI::GetCorporationsCorporationIdStarbasesStarbaseIdFuel](docs/GetCorporationsCorporationIdStarbasesStarbaseIdFuel.md)
 - [ESI::GetCorporationsCorporationIdStarbasesStarbaseIdOk](docs/GetCorporationsCorporationIdStarbasesStarbaseIdOk.md)
 - [ESI::GetCorporationsCorporationIdStructures200Ok](docs/GetCorporationsCorporationIdStructures200Ok.md)
 - [ESI::GetCorporationsCorporationIdStructuresService](docs/GetCorporationsCorporationIdStructuresService.md)
 - [ESI::GetCorporationsCorporationIdTitles200Ok](docs/GetCorporationsCorporationIdTitles200Ok.md)
 - [ESI::GetCorporationsCorporationIdWallets200Ok](docs/GetCorporationsCorporationIdWallets200Ok.md)
 - [ESI::GetCorporationsCorporationIdWalletsDivisionJournal200Ok](docs/GetCorporationsCorporationIdWalletsDivisionJournal200Ok.md)
 - [ESI::GetCorporationsCorporationIdWalletsDivisionTransactions200Ok](docs/GetCorporationsCorporationIdWalletsDivisionTransactions200Ok.md)
 - [ESI::GetDogmaAttributesAttributeIdNotFound](docs/GetDogmaAttributesAttributeIdNotFound.md)
 - [ESI::GetDogmaAttributesAttributeIdOk](docs/GetDogmaAttributesAttributeIdOk.md)
 - [ESI::GetDogmaDynamicItemsTypeIdItemIdDogmaAttribute](docs/GetDogmaDynamicItemsTypeIdItemIdDogmaAttribute.md)
 - [ESI::GetDogmaDynamicItemsTypeIdItemIdDogmaEffect](docs/GetDogmaDynamicItemsTypeIdItemIdDogmaEffect.md)
 - [ESI::GetDogmaDynamicItemsTypeIdItemIdNotFound](docs/GetDogmaDynamicItemsTypeIdItemIdNotFound.md)
 - [ESI::GetDogmaDynamicItemsTypeIdItemIdOk](docs/GetDogmaDynamicItemsTypeIdItemIdOk.md)
 - [ESI::GetDogmaEffectsEffectIdModifier](docs/GetDogmaEffectsEffectIdModifier.md)
 - [ESI::GetDogmaEffectsEffectIdNotFound](docs/GetDogmaEffectsEffectIdNotFound.md)
 - [ESI::GetDogmaEffectsEffectIdOk](docs/GetDogmaEffectsEffectIdOk.md)
 - [ESI::GetFleetsFleetIdMembers200Ok](docs/GetFleetsFleetIdMembers200Ok.md)
 - [ESI::GetFleetsFleetIdMembersNotFound](docs/GetFleetsFleetIdMembersNotFound.md)
 - [ESI::GetFleetsFleetIdNotFound](docs/GetFleetsFleetIdNotFound.md)
 - [ESI::GetFleetsFleetIdOk](docs/GetFleetsFleetIdOk.md)
 - [ESI::GetFleetsFleetIdWings200Ok](docs/GetFleetsFleetIdWings200Ok.md)
 - [ESI::GetFleetsFleetIdWingsNotFound](docs/GetFleetsFleetIdWingsNotFound.md)
 - [ESI::GetFleetsFleetIdWingsSquad](docs/GetFleetsFleetIdWingsSquad.md)
 - [ESI::GetFwLeaderboardsActiveTotalActiveTotal](docs/GetFwLeaderboardsActiveTotalActiveTotal.md)
 - [ESI::GetFwLeaderboardsActiveTotalActiveTotal1](docs/GetFwLeaderboardsActiveTotalActiveTotal1.md)
 - [ESI::GetFwLeaderboardsCharactersActiveTotalActiveTotal](docs/GetFwLeaderboardsCharactersActiveTotalActiveTotal.md)
 - [ESI::GetFwLeaderboardsCharactersActiveTotalActiveTotal1](docs/GetFwLeaderboardsCharactersActiveTotalActiveTotal1.md)
 - [ESI::GetFwLeaderboardsCharactersKills](docs/GetFwLeaderboardsCharactersKills.md)
 - [ESI::GetFwLeaderboardsCharactersLastWeekLastWeek](docs/GetFwLeaderboardsCharactersLastWeekLastWeek.md)
 - [ESI::GetFwLeaderboardsCharactersLastWeekLastWeek1](docs/GetFwLeaderboardsCharactersLastWeekLastWeek1.md)
 - [ESI::GetFwLeaderboardsCharactersOk](docs/GetFwLeaderboardsCharactersOk.md)
 - [ESI::GetFwLeaderboardsCharactersVictoryPoints](docs/GetFwLeaderboardsCharactersVictoryPoints.md)
 - [ESI::GetFwLeaderboardsCharactersYesterdayYesterday](docs/GetFwLeaderboardsCharactersYesterdayYesterday.md)
 - [ESI::GetFwLeaderboardsCharactersYesterdayYesterday1](docs/GetFwLeaderboardsCharactersYesterdayYesterday1.md)
 - [ESI::GetFwLeaderboardsCorporationsActiveTotalActiveTotal](docs/GetFwLeaderboardsCorporationsActiveTotalActiveTotal.md)
 - [ESI::GetFwLeaderboardsCorporationsActiveTotalActiveTotal1](docs/GetFwLeaderboardsCorporationsActiveTotalActiveTotal1.md)
 - [ESI::GetFwLeaderboardsCorporationsKills](docs/GetFwLeaderboardsCorporationsKills.md)
 - [ESI::GetFwLeaderboardsCorporationsLastWeekLastWeek](docs/GetFwLeaderboardsCorporationsLastWeekLastWeek.md)
 - [ESI::GetFwLeaderboardsCorporationsLastWeekLastWeek1](docs/GetFwLeaderboardsCorporationsLastWeekLastWeek1.md)
 - [ESI::GetFwLeaderboardsCorporationsOk](docs/GetFwLeaderboardsCorporationsOk.md)
 - [ESI::GetFwLeaderboardsCorporationsVictoryPoints](docs/GetFwLeaderboardsCorporationsVictoryPoints.md)
 - [ESI::GetFwLeaderboardsCorporationsYesterdayYesterday](docs/GetFwLeaderboardsCorporationsYesterdayYesterday.md)
 - [ESI::GetFwLeaderboardsCorporationsYesterdayYesterday1](docs/GetFwLeaderboardsCorporationsYesterdayYesterday1.md)
 - [ESI::GetFwLeaderboardsKills](docs/GetFwLeaderboardsKills.md)
 - [ESI::GetFwLeaderboardsLastWeekLastWeek](docs/GetFwLeaderboardsLastWeekLastWeek.md)
 - [ESI::GetFwLeaderboardsLastWeekLastWeek1](docs/GetFwLeaderboardsLastWeekLastWeek1.md)
 - [ESI::GetFwLeaderboardsOk](docs/GetFwLeaderboardsOk.md)
 - [ESI::GetFwLeaderboardsVictoryPoints](docs/GetFwLeaderboardsVictoryPoints.md)
 - [ESI::GetFwLeaderboardsYesterdayYesterday](docs/GetFwLeaderboardsYesterdayYesterday.md)
 - [ESI::GetFwLeaderboardsYesterdayYesterday1](docs/GetFwLeaderboardsYesterdayYesterday1.md)
 - [ESI::GetFwStats200Ok](docs/GetFwStats200Ok.md)
 - [ESI::GetFwStatsKills](docs/GetFwStatsKills.md)
 - [ESI::GetFwStatsVictoryPoints](docs/GetFwStatsVictoryPoints.md)
 - [ESI::GetFwSystems200Ok](docs/GetFwSystems200Ok.md)
 - [ESI::GetFwWars200Ok](docs/GetFwWars200Ok.md)
 - [ESI::GetIncursions200Ok](docs/GetIncursions200Ok.md)
 - [ESI::GetIndustryFacilities200Ok](docs/GetIndustryFacilities200Ok.md)
 - [ESI::GetIndustrySystems200Ok](docs/GetIndustrySystems200Ok.md)
 - [ESI::GetIndustrySystemsCostIndice](docs/GetIndustrySystemsCostIndice.md)
 - [ESI::GetInsurancePrices200Ok](docs/GetInsurancePrices200Ok.md)
 - [ESI::GetInsurancePricesLevel](docs/GetInsurancePricesLevel.md)
 - [ESI::GetKillmailsKillmailIdKillmailHashAttacker](docs/GetKillmailsKillmailIdKillmailHashAttacker.md)
 - [ESI::GetKillmailsKillmailIdKillmailHashItem](docs/GetKillmailsKillmailIdKillmailHashItem.md)
 - [ESI::GetKillmailsKillmailIdKillmailHashItemsItem](docs/GetKillmailsKillmailIdKillmailHashItemsItem.md)
 - [ESI::GetKillmailsKillmailIdKillmailHashOk](docs/GetKillmailsKillmailIdKillmailHashOk.md)
 - [ESI::GetKillmailsKillmailIdKillmailHashPosition](docs/GetKillmailsKillmailIdKillmailHashPosition.md)
 - [ESI::GetKillmailsKillmailIdKillmailHashUnprocessableEntity](docs/GetKillmailsKillmailIdKillmailHashUnprocessableEntity.md)
 - [ESI::GetKillmailsKillmailIdKillmailHashVictim](docs/GetKillmailsKillmailIdKillmailHashVictim.md)
 - [ESI::GetLoyaltyStoresCorporationIdOffers200Ok](docs/GetLoyaltyStoresCorporationIdOffers200Ok.md)
 - [ESI::GetLoyaltyStoresCorporationIdOffersNotFound](docs/GetLoyaltyStoresCorporationIdOffersNotFound.md)
 - [ESI::GetLoyaltyStoresCorporationIdOffersRequiredItem](docs/GetLoyaltyStoresCorporationIdOffersRequiredItem.md)
 - [ESI::GetMarketsGroupsMarketGroupIdNotFound](docs/GetMarketsGroupsMarketGroupIdNotFound.md)
 - [ESI::GetMarketsGroupsMarketGroupIdOk](docs/GetMarketsGroupsMarketGroupIdOk.md)
 - [ESI::GetMarketsPrices200Ok](docs/GetMarketsPrices200Ok.md)
 - [ESI::GetMarketsRegionIdHistory200Ok](docs/GetMarketsRegionIdHistory200Ok.md)
 - [ESI::GetMarketsRegionIdHistoryError520](docs/GetMarketsRegionIdHistoryError520.md)
 - [ESI::GetMarketsRegionIdHistoryNotFound](docs/GetMarketsRegionIdHistoryNotFound.md)
 - [ESI::GetMarketsRegionIdHistoryUnprocessableEntity](docs/GetMarketsRegionIdHistoryUnprocessableEntity.md)
 - [ESI::GetMarketsRegionIdOrders200Ok](docs/GetMarketsRegionIdOrders200Ok.md)
 - [ESI::GetMarketsRegionIdOrdersNotFound](docs/GetMarketsRegionIdOrdersNotFound.md)
 - [ESI::GetMarketsRegionIdOrdersUnprocessableEntity](docs/GetMarketsRegionIdOrdersUnprocessableEntity.md)
 - [ESI::GetMarketsStructuresStructureId200Ok](docs/GetMarketsStructuresStructureId200Ok.md)
 - [ESI::GetOpportunitiesGroupsGroupIdOk](docs/GetOpportunitiesGroupsGroupIdOk.md)
 - [ESI::GetOpportunitiesTasksTaskIdOk](docs/GetOpportunitiesTasksTaskIdOk.md)
 - [ESI::GetRouteOriginDestinationNotFound](docs/GetRouteOriginDestinationNotFound.md)
 - [ESI::GetSearchOk](docs/GetSearchOk.md)
 - [ESI::GetSovereigntyCampaigns200Ok](docs/GetSovereigntyCampaigns200Ok.md)
 - [ESI::GetSovereigntyCampaignsParticipant](docs/GetSovereigntyCampaignsParticipant.md)
 - [ESI::GetSovereigntyMap200Ok](docs/GetSovereigntyMap200Ok.md)
 - [ESI::GetSovereigntyStructures200Ok](docs/GetSovereigntyStructures200Ok.md)
 - [ESI::GetStatusOk](docs/GetStatusOk.md)
 - [ESI::GetUniverseAncestries200Ok](docs/GetUniverseAncestries200Ok.md)
 - [ESI::GetUniverseAsteroidBeltsAsteroidBeltIdNotFound](docs/GetUniverseAsteroidBeltsAsteroidBeltIdNotFound.md)
 - [ESI::GetUniverseAsteroidBeltsAsteroidBeltIdOk](docs/GetUniverseAsteroidBeltsAsteroidBeltIdOk.md)
 - [ESI::GetUniverseAsteroidBeltsAsteroidBeltIdPosition](docs/GetUniverseAsteroidBeltsAsteroidBeltIdPosition.md)
 - [ESI::GetUniverseBloodlines200Ok](docs/GetUniverseBloodlines200Ok.md)
 - [ESI::GetUniverseCategoriesCategoryIdNotFound](docs/GetUniverseCategoriesCategoryIdNotFound.md)
 - [ESI::GetUniverseCategoriesCategoryIdOk](docs/GetUniverseCategoriesCategoryIdOk.md)
 - [ESI::GetUniverseConstellationsConstellationIdNotFound](docs/GetUniverseConstellationsConstellationIdNotFound.md)
 - [ESI::GetUniverseConstellationsConstellationIdOk](docs/GetUniverseConstellationsConstellationIdOk.md)
 - [ESI::GetUniverseConstellationsConstellationIdPosition](docs/GetUniverseConstellationsConstellationIdPosition.md)
 - [ESI::GetUniverseFactions200Ok](docs/GetUniverseFactions200Ok.md)
 - [ESI::GetUniverseGraphicsGraphicIdNotFound](docs/GetUniverseGraphicsGraphicIdNotFound.md)
 - [ESI::GetUniverseGraphicsGraphicIdOk](docs/GetUniverseGraphicsGraphicIdOk.md)
 - [ESI::GetUniverseGroupsGroupIdNotFound](docs/GetUniverseGroupsGroupIdNotFound.md)
 - [ESI::GetUniverseGroupsGroupIdOk](docs/GetUniverseGroupsGroupIdOk.md)
 - [ESI::GetUniverseMoonsMoonIdNotFound](docs/GetUniverseMoonsMoonIdNotFound.md)
 - [ESI::GetUniverseMoonsMoonIdOk](docs/GetUniverseMoonsMoonIdOk.md)
 - [ESI::GetUniverseMoonsMoonIdPosition](docs/GetUniverseMoonsMoonIdPosition.md)
 - [ESI::GetUniversePlanetsPlanetIdNotFound](docs/GetUniversePlanetsPlanetIdNotFound.md)
 - [ESI::GetUniversePlanetsPlanetIdOk](docs/GetUniversePlanetsPlanetIdOk.md)
 - [ESI::GetUniversePlanetsPlanetIdPosition](docs/GetUniversePlanetsPlanetIdPosition.md)
 - [ESI::GetUniverseRaces200Ok](docs/GetUniverseRaces200Ok.md)
 - [ESI::GetUniverseRegionsRegionIdNotFound](docs/GetUniverseRegionsRegionIdNotFound.md)
 - [ESI::GetUniverseRegionsRegionIdOk](docs/GetUniverseRegionsRegionIdOk.md)
 - [ESI::GetUniverseSchematicsSchematicIdNotFound](docs/GetUniverseSchematicsSchematicIdNotFound.md)
 - [ESI::GetUniverseSchematicsSchematicIdOk](docs/GetUniverseSchematicsSchematicIdOk.md)
 - [ESI::GetUniverseStargatesStargateIdDestination](docs/GetUniverseStargatesStargateIdDestination.md)
 - [ESI::GetUniverseStargatesStargateIdNotFound](docs/GetUniverseStargatesStargateIdNotFound.md)
 - [ESI::GetUniverseStargatesStargateIdOk](docs/GetUniverseStargatesStargateIdOk.md)
 - [ESI::GetUniverseStargatesStargateIdPosition](docs/GetUniverseStargatesStargateIdPosition.md)
 - [ESI::GetUniverseStarsStarIdOk](docs/GetUniverseStarsStarIdOk.md)
 - [ESI::GetUniverseStationsStationIdNotFound](docs/GetUniverseStationsStationIdNotFound.md)
 - [ESI::GetUniverseStationsStationIdOk](docs/GetUniverseStationsStationIdOk.md)
 - [ESI::GetUniverseStationsStationIdPosition](docs/GetUniverseStationsStationIdPosition.md)
 - [ESI::GetUniverseStructuresStructureIdNotFound](docs/GetUniverseStructuresStructureIdNotFound.md)
 - [ESI::GetUniverseStructuresStructureIdOk](docs/GetUniverseStructuresStructureIdOk.md)
 - [ESI::GetUniverseStructuresStructureIdPosition](docs/GetUniverseStructuresStructureIdPosition.md)
 - [ESI::GetUniverseSystemJumps200Ok](docs/GetUniverseSystemJumps200Ok.md)
 - [ESI::GetUniverseSystemKills200Ok](docs/GetUniverseSystemKills200Ok.md)
 - [ESI::GetUniverseSystemsSystemIdNotFound](docs/GetUniverseSystemsSystemIdNotFound.md)
 - [ESI::GetUniverseSystemsSystemIdOk](docs/GetUniverseSystemsSystemIdOk.md)
 - [ESI::GetUniverseSystemsSystemIdPlanet](docs/GetUniverseSystemsSystemIdPlanet.md)
 - [ESI::GetUniverseSystemsSystemIdPosition](docs/GetUniverseSystemsSystemIdPosition.md)
 - [ESI::GetUniverseTypesTypeIdDogmaAttribute](docs/GetUniverseTypesTypeIdDogmaAttribute.md)
 - [ESI::GetUniverseTypesTypeIdDogmaEffect](docs/GetUniverseTypesTypeIdDogmaEffect.md)
 - [ESI::GetUniverseTypesTypeIdNotFound](docs/GetUniverseTypesTypeIdNotFound.md)
 - [ESI::GetUniverseTypesTypeIdOk](docs/GetUniverseTypesTypeIdOk.md)
 - [ESI::GetWarsWarIdAggressor](docs/GetWarsWarIdAggressor.md)
 - [ESI::GetWarsWarIdAlly](docs/GetWarsWarIdAlly.md)
 - [ESI::GetWarsWarIdDefender](docs/GetWarsWarIdDefender.md)
 - [ESI::GetWarsWarIdKillmails200Ok](docs/GetWarsWarIdKillmails200Ok.md)
 - [ESI::GetWarsWarIdKillmailsUnprocessableEntity](docs/GetWarsWarIdKillmailsUnprocessableEntity.md)
 - [ESI::GetWarsWarIdOk](docs/GetWarsWarIdOk.md)
 - [ESI::GetWarsWarIdUnprocessableEntity](docs/GetWarsWarIdUnprocessableEntity.md)
 - [ESI::InternalServerError](docs/InternalServerError.md)
 - [ESI::PostCharactersAffiliation200Ok](docs/PostCharactersAffiliation200Ok.md)
 - [ESI::PostCharactersAffiliationNotFound](docs/PostCharactersAffiliationNotFound.md)
 - [ESI::PostCharactersCharacterIdAssetsLocations200Ok](docs/PostCharactersCharacterIdAssetsLocations200Ok.md)
 - [ESI::PostCharactersCharacterIdAssetsLocationsPosition](docs/PostCharactersCharacterIdAssetsLocationsPosition.md)
 - [ESI::PostCharactersCharacterIdAssetsNames200Ok](docs/PostCharactersCharacterIdAssetsNames200Ok.md)
 - [ESI::PostCharactersCharacterIdContactsError520](docs/PostCharactersCharacterIdContactsError520.md)
 - [ESI::PostCharactersCharacterIdFittingsCreated](docs/PostCharactersCharacterIdFittingsCreated.md)
 - [ESI::PostCharactersCharacterIdFittingsFitting](docs/PostCharactersCharacterIdFittingsFitting.md)
 - [ESI::PostCharactersCharacterIdFittingsItem](docs/PostCharactersCharacterIdFittingsItem.md)
 - [ESI::PostCharactersCharacterIdMailError520](docs/PostCharactersCharacterIdMailError520.md)
 - [ESI::PostCharactersCharacterIdMailLabelsLabel](docs/PostCharactersCharacterIdMailLabelsLabel.md)
 - [ESI::PostCharactersCharacterIdMailMail](docs/PostCharactersCharacterIdMailMail.md)
 - [ESI::PostCharactersCharacterIdMailRecipient](docs/PostCharactersCharacterIdMailRecipient.md)
 - [ESI::PostCorporationsCorporationIdAssetsLocations200Ok](docs/PostCorporationsCorporationIdAssetsLocations200Ok.md)
 - [ESI::PostCorporationsCorporationIdAssetsLocationsNotFound](docs/PostCorporationsCorporationIdAssetsLocationsNotFound.md)
 - [ESI::PostCorporationsCorporationIdAssetsLocationsPosition](docs/PostCorporationsCorporationIdAssetsLocationsPosition.md)
 - [ESI::PostCorporationsCorporationIdAssetsNames200Ok](docs/PostCorporationsCorporationIdAssetsNames200Ok.md)
 - [ESI::PostCorporationsCorporationIdAssetsNamesNotFound](docs/PostCorporationsCorporationIdAssetsNamesNotFound.md)
 - [ESI::PostFleetsFleetIdMembersInvitation](docs/PostFleetsFleetIdMembersInvitation.md)
 - [ESI::PostFleetsFleetIdMembersNotFound](docs/PostFleetsFleetIdMembersNotFound.md)
 - [ESI::PostFleetsFleetIdMembersUnprocessableEntity](docs/PostFleetsFleetIdMembersUnprocessableEntity.md)
 - [ESI::PostFleetsFleetIdWingsCreated](docs/PostFleetsFleetIdWingsCreated.md)
 - [ESI::PostFleetsFleetIdWingsNotFound](docs/PostFleetsFleetIdWingsNotFound.md)
 - [ESI::PostFleetsFleetIdWingsWingIdSquadsCreated](docs/PostFleetsFleetIdWingsWingIdSquadsCreated.md)
 - [ESI::PostFleetsFleetIdWingsWingIdSquadsNotFound](docs/PostFleetsFleetIdWingsWingIdSquadsNotFound.md)
 - [ESI::PostUiOpenwindowNewmailNewMail](docs/PostUiOpenwindowNewmailNewMail.md)
 - [ESI::PostUiOpenwindowNewmailUnprocessableEntity](docs/PostUiOpenwindowNewmailUnprocessableEntity.md)
 - [ESI::PostUniverseIdsAgent](docs/PostUniverseIdsAgent.md)
 - [ESI::PostUniverseIdsAlliance](docs/PostUniverseIdsAlliance.md)
 - [ESI::PostUniverseIdsCharacter](docs/PostUniverseIdsCharacter.md)
 - [ESI::PostUniverseIdsConstellation](docs/PostUniverseIdsConstellation.md)
 - [ESI::PostUniverseIdsCorporation](docs/PostUniverseIdsCorporation.md)
 - [ESI::PostUniverseIdsFaction](docs/PostUniverseIdsFaction.md)
 - [ESI::PostUniverseIdsInventoryType](docs/PostUniverseIdsInventoryType.md)
 - [ESI::PostUniverseIdsOk](docs/PostUniverseIdsOk.md)
 - [ESI::PostUniverseIdsRegion](docs/PostUniverseIdsRegion.md)
 - [ESI::PostUniverseIdsStation](docs/PostUniverseIdsStation.md)
 - [ESI::PostUniverseIdsSystem](docs/PostUniverseIdsSystem.md)
 - [ESI::PostUniverseNames200Ok](docs/PostUniverseNames200Ok.md)
 - [ESI::PostUniverseNamesNotFound](docs/PostUniverseNamesNotFound.md)
 - [ESI::PutCharactersCharacterIdCalendarEventIdResponse](docs/PutCharactersCharacterIdCalendarEventIdResponse.md)
 - [ESI::PutCharactersCharacterIdMailMailIdContents](docs/PutCharactersCharacterIdMailMailIdContents.md)
 - [ESI::PutFleetsFleetIdMembersMemberIdMovement](docs/PutFleetsFleetIdMembersMemberIdMovement.md)
 - [ESI::PutFleetsFleetIdMembersMemberIdNotFound](docs/PutFleetsFleetIdMembersMemberIdNotFound.md)
 - [ESI::PutFleetsFleetIdMembersMemberIdUnprocessableEntity](docs/PutFleetsFleetIdMembersMemberIdUnprocessableEntity.md)
 - [ESI::PutFleetsFleetIdNewSettings](docs/PutFleetsFleetIdNewSettings.md)
 - [ESI::PutFleetsFleetIdNotFound](docs/PutFleetsFleetIdNotFound.md)
 - [ESI::PutFleetsFleetIdSquadsSquadIdNaming](docs/PutFleetsFleetIdSquadsSquadIdNaming.md)
 - [ESI::PutFleetsFleetIdSquadsSquadIdNotFound](docs/PutFleetsFleetIdSquadsSquadIdNotFound.md)
 - [ESI::PutFleetsFleetIdWingsWingIdNaming](docs/PutFleetsFleetIdWingsWingIdNaming.md)
 - [ESI::PutFleetsFleetIdWingsWingIdNotFound](docs/PutFleetsFleetIdWingsWingIdNotFound.md)
 - [ESI::ServiceUnavailable](docs/ServiceUnavailable.md)
 - [ESI::Unauthorized](docs/Unauthorized.md)


## Documentation for Authorization


### evesso

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://login.eveonline.com/v2/oauth/authorize
- **Scopes**: 
  - esi-alliances.read_contacts.v1: EVE SSO scope esi-alliances.read_contacts.v1
  - esi-assets.read_assets.v1: EVE SSO scope esi-assets.read_assets.v1
  - esi-assets.read_corporation_assets.v1: EVE SSO scope esi-assets.read_corporation_assets.v1
  - esi-bookmarks.read_character_bookmarks.v1: EVE SSO scope esi-bookmarks.read_character_bookmarks.v1
  - esi-bookmarks.read_corporation_bookmarks.v1: EVE SSO scope esi-bookmarks.read_corporation_bookmarks.v1
  - esi-calendar.read_calendar_events.v1: EVE SSO scope esi-calendar.read_calendar_events.v1
  - esi-calendar.respond_calendar_events.v1: EVE SSO scope esi-calendar.respond_calendar_events.v1
  - esi-characters.read_agents_research.v1: EVE SSO scope esi-characters.read_agents_research.v1
  - esi-characters.read_blueprints.v1: EVE SSO scope esi-characters.read_blueprints.v1
  - esi-characters.read_contacts.v1: EVE SSO scope esi-characters.read_contacts.v1
  - esi-characters.read_corporation_roles.v1: EVE SSO scope esi-characters.read_corporation_roles.v1
  - esi-characters.read_fatigue.v1: EVE SSO scope esi-characters.read_fatigue.v1
  - esi-characters.read_fw_stats.v1: EVE SSO scope esi-characters.read_fw_stats.v1
  - esi-characters.read_loyalty.v1: EVE SSO scope esi-characters.read_loyalty.v1
  - esi-characters.read_medals.v1: EVE SSO scope esi-characters.read_medals.v1
  - esi-characters.read_notifications.v1: EVE SSO scope esi-characters.read_notifications.v1
  - esi-characters.read_opportunities.v1: EVE SSO scope esi-characters.read_opportunities.v1
  - esi-characters.read_standings.v1: EVE SSO scope esi-characters.read_standings.v1
  - esi-characters.read_titles.v1: EVE SSO scope esi-characters.read_titles.v1
  - esi-characters.write_contacts.v1: EVE SSO scope esi-characters.write_contacts.v1
  - esi-characterstats.read.v1: EVE SSO scope esi-characterstats.read.v1
  - esi-clones.read_clones.v1: EVE SSO scope esi-clones.read_clones.v1
  - esi-clones.read_implants.v1: EVE SSO scope esi-clones.read_implants.v1
  - esi-contracts.read_character_contracts.v1: EVE SSO scope esi-contracts.read_character_contracts.v1
  - esi-contracts.read_corporation_contracts.v1: EVE SSO scope esi-contracts.read_corporation_contracts.v1
  - esi-corporations.read_blueprints.v1: EVE SSO scope esi-corporations.read_blueprints.v1
  - esi-corporations.read_contacts.v1: EVE SSO scope esi-corporations.read_contacts.v1
  - esi-corporations.read_container_logs.v1: EVE SSO scope esi-corporations.read_container_logs.v1
  - esi-corporations.read_corporation_membership.v1: EVE SSO scope esi-corporations.read_corporation_membership.v1
  - esi-corporations.read_divisions.v1: EVE SSO scope esi-corporations.read_divisions.v1
  - esi-corporations.read_facilities.v1: EVE SSO scope esi-corporations.read_facilities.v1
  - esi-corporations.read_fw_stats.v1: EVE SSO scope esi-corporations.read_fw_stats.v1
  - esi-corporations.read_medals.v1: EVE SSO scope esi-corporations.read_medals.v1
  - esi-corporations.read_standings.v1: EVE SSO scope esi-corporations.read_standings.v1
  - esi-corporations.read_starbases.v1: EVE SSO scope esi-corporations.read_starbases.v1
  - esi-corporations.read_structures.v1: EVE SSO scope esi-corporations.read_structures.v1
  - esi-corporations.read_titles.v1: EVE SSO scope esi-corporations.read_titles.v1
  - esi-corporations.track_members.v1: EVE SSO scope esi-corporations.track_members.v1
  - esi-fittings.read_fittings.v1: EVE SSO scope esi-fittings.read_fittings.v1
  - esi-fittings.write_fittings.v1: EVE SSO scope esi-fittings.write_fittings.v1
  - esi-fleets.read_fleet.v1: EVE SSO scope esi-fleets.read_fleet.v1
  - esi-fleets.write_fleet.v1: EVE SSO scope esi-fleets.write_fleet.v1
  - esi-industry.read_character_jobs.v1: EVE SSO scope esi-industry.read_character_jobs.v1
  - esi-industry.read_character_mining.v1: EVE SSO scope esi-industry.read_character_mining.v1
  - esi-industry.read_corporation_jobs.v1: EVE SSO scope esi-industry.read_corporation_jobs.v1
  - esi-industry.read_corporation_mining.v1: EVE SSO scope esi-industry.read_corporation_mining.v1
  - esi-killmails.read_corporation_killmails.v1: EVE SSO scope esi-killmails.read_corporation_killmails.v1
  - esi-killmails.read_killmails.v1: EVE SSO scope esi-killmails.read_killmails.v1
  - esi-location.read_location.v1: EVE SSO scope esi-location.read_location.v1
  - esi-location.read_online.v1: EVE SSO scope esi-location.read_online.v1
  - esi-location.read_ship_type.v1: EVE SSO scope esi-location.read_ship_type.v1
  - esi-mail.organize_mail.v1: EVE SSO scope esi-mail.organize_mail.v1
  - esi-mail.read_mail.v1: EVE SSO scope esi-mail.read_mail.v1
  - esi-mail.send_mail.v1: EVE SSO scope esi-mail.send_mail.v1
  - esi-markets.read_character_orders.v1: EVE SSO scope esi-markets.read_character_orders.v1
  - esi-markets.read_corporation_orders.v1: EVE SSO scope esi-markets.read_corporation_orders.v1
  - esi-markets.structure_markets.v1: EVE SSO scope esi-markets.structure_markets.v1
  - esi-planets.manage_planets.v1: EVE SSO scope esi-planets.manage_planets.v1
  - esi-planets.read_customs_offices.v1: EVE SSO scope esi-planets.read_customs_offices.v1
  - esi-search.search_structures.v1: EVE SSO scope esi-search.search_structures.v1
  - esi-skills.read_skillqueue.v1: EVE SSO scope esi-skills.read_skillqueue.v1
  - esi-skills.read_skills.v1: EVE SSO scope esi-skills.read_skills.v1
  - esi-ui.open_window.v1: EVE SSO scope esi-ui.open_window.v1
  - esi-ui.write_waypoint.v1: EVE SSO scope esi-ui.write_waypoint.v1
  - esi-universe.read_structures.v1: EVE SSO scope esi-universe.read_structures.v1
  - esi-wallet.read_character_wallet.v1: EVE SSO scope esi-wallet.read_character_wallet.v1
  - esi-wallet.read_corporation_wallets.v1: EVE SSO scope esi-wallet.read_corporation_wallets.v1

